@@ -4,14 +4,13 @@ import 'dart:io';
 
 import 'package:fvm/src/runner.dart';
 import 'package:fvm/src/utils/context.dart';
-import 'package:scope/scope.dart';
 
 Future<void> main(List<String> args) async {
-  final scope = Scope()..value(contextKey, FVMContext.create(args: args));
+  final updatableArgs = [...args];
+  final skipInput = updatableArgs.remove('--fvm-skip-input');
+  final controller = FvmContext.create(skipInput: skipInput);
 
-  await _flushThenExit(
-    await scope.run(() async => FvmCommandRunner().run((ctx.args))),
-  );
+  await _flushThenExit(await FvmCommandRunner(controller).run(updatableArgs));
 }
 
 /// Flushes the stdout and stderr streams, then exits the program with the given
