@@ -1,11 +1,27 @@
 import 'package:args/command_runner.dart';
+import 'package:meta/meta.dart';
+
+import '../services/base_service.dart';
+import '../services/logger_service.dart';
+import '../utils/context.dart';
 
 /// Base Command
-abstract class BaseCommand extends Command<int> {
-  BaseCommand();
+abstract class BaseFvmCommand extends Command<int> {
+  @protected
+  final FvmContext context;
+
+  BaseFvmCommand(this.context);
+
+  Logger get logger => context.get();
+
+  T get<T extends Contextual>() => context.get();
 
   @override
   String get invocation => 'fvm $name';
+
+  // Override to make sure commands are visible by default
+  @override
+  bool get hidden => false;
 }
 
 extension CommandExtension on Command {
@@ -32,6 +48,9 @@ extension CommandExtension on Command {
   }
 
   /// Gets the parsed command-line option named [name] as `List<String>`.
-  // ignore: prefer-correct-json-casts
-  List<String?> stringsArg(String name) => argResults![name] as List<String>;
+  List<String?> stringsArg(String name) => (argResults![name] as List).cast();
+
+  /// Gets the first rest argument if available, otherwise returns null
+  String? get firstRestArg =>
+      argResults!.rest.isEmpty ? null : argResults!.rest[0];
 }
