@@ -69,6 +69,12 @@ class FvmCommandRunner extends CompletionCommandRunner<int> {
     addCommand(IntegrationTestCommand(context));
   }
 
+  /// Disable auto-install of shell completions to avoid PathAccessException
+  /// in managed environments (Nix/Home Manager) where shell configs are read-only.
+  /// Users can still manually install completions via `fvm completion install`.
+  @override
+  bool get enableAutoInstall => false;
+
   /// Checks if the current version (set by the build runner on the
   /// version.dart file) is the most recent one. If not, show a prompt to the
   /// user.
